ValidationError

Enum ValidationError 

pub enum ValidationError {
    FileNotFound {
        path: PathBuf,
        arg_name: String,
        suggestion: Option<String>,
    },
    InvalidExtension {
        arg_name: String,
        path: PathBuf,
        expected: Vec<String>,
    },
    OutOfRange {
        arg_name: String,
        value: f64,
        min: f64,
        max: f64,
        suggestion: Option<String>,
    },
    CustomConstraint {
        arg_name: String,
        reason: String,
        suggestion: Option<String>,
    },
    MissingDependency {
        arg_name: String,
        required_arg: String,
        suggestion: Option<String>,
    },
    MutuallyExclusive {
        arg1: String,
        arg2: String,
        suggestion: Option<String>,
    },
}
Errors during argument validation

These errors occur after parsing, during validation of constraints defined in the configuration.

Variants



FileNotFound

Required file doesn’t exist

Example

use dynamic_cli::error::ValidationError;
use std::path::PathBuf;

let error = ValidationError::FileNotFound {
    path: PathBuf::from("data.csv"),
    arg_name: "input".to_string(),
    suggestion: Some("Check that the file exists and the path is correct.".to_string()),
};
let msg = format!("{}", error);
assert!(msg.contains("data.csv"));

Fields

path: PathBuf
arg_name: String
suggestion: Option<String>

Actionable hint surfaced to the user (not part of the Display string)



InvalidExtension

Invalid file extension

Fields

arg_name: String
path: PathBuf
expected: Vec<String>


OutOfRange

Value out of allowed range

Example

use dynamic_cli::error::ValidationError;

let error = ValidationError::OutOfRange {
    arg_name: "percentage".to_string(),
    value: 150.0,
    min: 0.0,
    max: 100.0,
    suggestion: Some("Value must be between 0 and 100.".to_string()),
};
let msg = format!("{}", error);
assert!(msg.contains("150"));

Fields

arg_name: String
value: f64
min: f64
max: f64
suggestion: Option<String>

Actionable hint surfaced to the user (not part of the Display string)



CustomConstraint

Custom constraint not met

Example

use dynamic_cli::error::ValidationError;

let error = ValidationError::CustomConstraint {
    arg_name: "email".to_string(),
    reason: "not a valid email address".to_string(),
    suggestion: Some("Provide a valid email address (e.g. user@example.com).".to_string()),
};
let msg = format!("{}", error);
assert!(msg.contains("email"));

Fields

arg_name: String
reason: String
suggestion: Option<String>

Actionable hint surfaced to the user (not part of the Display string)



MissingDependency

Dependency between arguments not satisfied

Some arguments require the presence of other arguments.

Example

use dynamic_cli::error::ValidationError;

let error = ValidationError::MissingDependency {
    arg_name: "output-format".to_string(),
    required_arg: "output".to_string(),
    suggestion: Some("Add --output to your command.".to_string()),
};
let msg = format!("{}", error);
assert!(msg.contains("output-format"));

Fields

arg_name: String
required_arg: String
suggestion: Option<String>

Actionable hint surfaced to the user (not part of the Display string)



MutuallyExclusive

Mutually exclusive arguments

Some arguments cannot be used together.

Example

use dynamic_cli::error::ValidationError;

let error = ValidationError::MutuallyExclusive {
    arg1: "--verbose".to_string(),
    arg2: "--quiet".to_string(),
    suggestion: Some("Remove one of the two conflicting options.".to_string()),
};
let msg = format!("{}", error);
assert!(msg.contains("--verbose"));

Fields

arg1: String
arg2: String
suggestion: Option<String>

Actionable hint surfaced to the user (not part of the Display string)